import os
from datetime import datetime
import subprocess
import requests  # Upewnij się, że masz zainstalowaną bibliotekę requests

def send_discord_notification(webhook_url, message):
    data = {
        'content': message
    }
    requests.post(webhook_url, json=data)

def rsync_from_remote(config, source_folder, destination_folder, backup_datetime, webhook_url):
    try:
        # Utwórz polecenie rsync, dodając opcję --include
        rsync_command = [
            'rsync',
            '-avz',
            '-e', f"ssh -i {config['private_key_path']} -p {config['ssh_port']} -v",
            '--include', f"*_{backup_datetime}*",
            '--exclude', '*',  # Wyklucz wszystko, co nie pasuje do wzorca include
            f"{config['remote_host']}:{config['remote_backup_folder']}/{source_folder}/",
            destination_folder
        ]

        # Wywołaj polecenie rsync przy użyciu subprocess
        exit_code = subprocess.run(rsync_command).returncode

        if exit_code == 0:
            success_message = f"🎉 Super! Kopię zapasową z serwera {config['remote_host']} udało się pomyślnie pobrać. 🚀"
            print(success_message)
            send_discord_notification(webhook_url, success_message)
        else:
            error_message = f"❌ Oops! Wystąpił błąd podczas pobierania kopii zapasowej z serwera {config['remote_host']}. Sprawdź logi i ponownie spróbuj. 😞"
            print(error_message)
            send_discord_notification(webhook_url, error_message)

    except Exception as e:
        error_message = f"Błąd podczas połączenia z {config['remote_host']}: {e}"
        print(error_message)
        send_discord_notification(webhook_url, error_message)

def main():
    # Tutaj wczytaj konfigurację z pliku lub innej odpowiedniej lokalizacji
    config = {
        'remote_servers': [
            {'remote_host': 'exmaplehost1', 'private_key_path': 'sciezka/do/klucza/id_rsa', 'source_folder': 'backups', 'destination_folder': '/home/kopieS1/', 'remote_backup_folder': '/root/', 'ssh_port': 22},
            {'remote_host': 'examplehost2', 'private_key_path': 'sciezka/do/klucza/id_rsa', 'source_folder': 'backups', 'destination_folder': '/home/kopieS2/', 'remote_backup_folder': '/root/', 'ssh_port': 22},
            # Dodaj więcej serwerów zdalnych w odpowiednim formacie
        ],
        'discord_webhook_url': 'https://discord.com/api/webhooks/xxxxxxxxxxxxxxx/xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'
    }

    # Dostosuj tę zmienną do żądanej daty i czasu
    backup_datetime = datetime.now().strftime('%Y%m%d')

    for server_config in config['remote_servers']:
        server_destination_folder = os.path.join(server_config['destination_folder'], f"backup_{server_config['remote_host']}_{backup_datetime}")
        os.makedirs(server_destination_folder, exist_ok=True)  # Utwórz folder docelowy, jeśli nie istnieje
        rsync_from_remote(server_config, server_config['source_folder'], server_destination_folder, backup_datetime, config['discord_webhook_url'])

if __name__ == "__main__":
    main()
